@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/functions.c,v 1.80 2006/05/10 14:12:30 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/functions.c,v 1.82 2006/08/09 16:54:01 richb Exp $
  *
  *  Copyright (c) 1987-2006 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -120,23 +120,17 @@ purge_redo_history(void)
 	} while (i != v->h.end);
     }
 
-#if 0
-    while (i != v->h.end) {
-	free(v->h.e[i].expression);
-	v->h.e[i].expression = NULL;
-	i = ((i + 1) % UNDO_HISTORY_LENGTH);
-    }
-#endif    
-
     v->h.end = v->h.current;
 }
 
 void
 new_state(void)
 {
+    int c;
+
     purge_redo_history();
 
-    int c = v->h.current;
+    c = v->h.current;
     v->h.end = v->h.current = ((v->h.current + 1) % UNDO_HISTORY_LENGTH);
     if (v->h.current == v->h.begin) {
 	free(v->h.e[v->h.begin].expression);
@@ -227,12 +221,13 @@ exp_append(char *text)
 {
     char *buf;
     int orig_len, dest_len;
+    struct exprm_state *e;
 
     if (!text) {
         return;
     }
 
-    struct exprm_state *e = get_state();
+    e = get_state();
 	
     orig_len = (e->expression) ? strlen(e->expression) : 0;
     dest_len = orig_len + strlen(text) +1;
@@ -449,10 +444,13 @@ trig_filter(char **func)
 void
 do_expression()
 {
+    char *btext = NULL;
+    struct exprm_state *e;
+    int non_empty_expression;
+
     update_statusbar("", "");
 
-    char *btext = NULL;
-    struct exprm_state *e = get_state();
+    e = get_state();
     if (e->button.flags & dpoint) {
 	btext = get_localized_numeric_point();
     } else {
@@ -461,7 +459,7 @@ do_expression()
     btext = gc_strdup(btext);
     trig_filter(&btext);
   
-    int non_empty_expression = !!(e->expression && strlen(e->expression));
+    non_empty_expression = !!(e->expression && strlen(e->expression));
 
     if (non_empty_expression) {
 	if (!strcmp(e->expression, "Ans")) {
@@ -1453,10 +1451,6 @@ do_shift()     /* Perform bitwise shift on display value. */
             calc_rshift(MPval, e->ans, n, dir);
 
 	    exp_replace("Ans");
-#if 0
-            exp_del();
-            exp_append(make_number(e->ans, v->base, FALSE));
-#endif
         }
         break;
 
